#!/bin/sh
# *******************************************************************************
#  Лицензионные материалы - собственность IBM
#  (c) Copyright IBM Corporation 2006, 2011. Все права защищены.
#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************
# NLS_MESSAGEFORMAT_NONE
# NLS_ENCODING=UTF-8


# #############################################################
# #
# # Определите переменные среды, соответствующие параметрам
# # сценария rm_upgrade.sh, и их значения по умолчанию
# #
# #===========================================================
# #
# # Этот файл считывается в начале каждого выполнения сценария
# # rm_upgrade.sh. Для каждого допустимого параметра он
# # инициализирует переменную среды предопределенным
# # значением по умолчанию.
# #
# # Пользователям может потребоваться изменить значение по
# # умолчанию, чтобы запускать rm_upgrade.sh со своими
# # значениями, не вводя параметр и его значение вручную
# # в командной строке.
# #
# # ПРЕДУПРЕЖДЕНИЕ:
# # Для некоторых приложений требуется указывать не все
# # переменные.  Внимательно ознакомьтесь с комментарием
# # перед изменением значения.
# #
# #############################################################

# Параметр: -oldApplicationHome
# Формат: -oldApplicationHome <путь-к-каталогу>
# Описание:
# 	Полный путь к домашнему каталогу приложения в установке
#  версии 2.x.
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - это обязательный параметр
#  - <путь-к-каталогу> должен существовать и оканчиваться на 'server/conf',
#    например: /Jazz/IBM/RRC_2.x/jazz/server/conf
#
OLD_APPLICATION_HOME=

# Параметр: -applicationContextRoot
# Формат: -applicationContextRoot <корень>
# Описание:
# 	Корневой контекст приложения сервера версии 2.x.
# Значение по умолчанию:
# 	rdm
# Ограничения:
#  - <корень> должен быть допустимым именем каталога
#   (то есть без начального символа косой черты)
#
APPLICATION_CONTEXT_ROOT=rdm

# Параметр: -oldJTSHome
# Формат: -oldJTSHome <путь-к-каталогу>
# Описание:
# 	Полный путь к домашнему каталогу JTS установки версии 2.x.
# Значение по умолчанию:
# 	<нет>
# Примечание:
#     Если указан, будет выполнено обновление RTC и JTS
#     с версии 3.0 до версии 3.0.1. В противном случае независимо
#     от типа обновления будет обработан только RTC.
# Ограничение:
#  - <путь-к-каталогу> должен существовать и оканчиваться на 'server/conf'
#  - Допустим только при обновлении RM и JTS
#
OLD_JTS_HOME=

# Параметр: -oldJTSContextRoot
# Формат: -oldJTSContextRoot <корень>
# Описание:
# 	Корневой контекст JTS сервера версии 2.x
# Значение по умолчанию:
# 	jazz
# Ограничения:
#  - Допустим только для обновления RM
#  - <корень> должен быть допустимым именем каталога
#   (то есть без начального символа косой черты)
#
OLD_JTS_CONTEXT_ROOT=jazz

# Параметр: -updateTomcatFiles
# Формат: -updateTomcatFiles <yes | no>
# Описание:
# 	Разрешает/запрещает обновление файлов конфигурации Tomcat.
# Значение по умолчанию:
# 	yes
# Ограничения:
#  - Допустимы только значения 'yes' и 'no'
#
UPDATE_TOMCAT_FILES=yes

# Параметр: -oldApplicationTomcatHome
# Формат: -oldApplicationTomcatHome <путь-к-каталогу>
# Описание:
# 	Полный путь к корневому каталогу Tomcat приложения в установке
#  версии 2.x.
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - Допустим только при обновлении RM
#  - Должен задавать существующий каталог
#
OLD_TOMCAT_HOME=

# Параметр: -oldJTSTomcatHome
# Формат: -oldJTSTomcatHome <путь-к-каталогу>
# Описание:
# 	Полный путь к корневому каталогу Tomcat JTS в установке версии 2.x.
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - Допустим только при обновлении RM
#  - Должен задавать существующий каталог
#
OLD_JTS_TOMCAT_HOME=

# Параметр: -newApplicationHome
# Формат: -newApplicationHome <путь-к-каталогу>
# Описание:
# 	Путь к домашнему каталогу приложения в установке версии 3.x.
# Значение по умолчанию:
# 	conf
# Ограничения:
#  - Допустим только при обновлении RTC, QM и RM
#  - Если допустим, то является обязательным
#  - <путь-к-каталогу> должен существовать и оканчиваться на 'server/conf',
#    например: /Jazz/IBM/RRC_3.0/JazzTeamServer/server/conf
#
NEW_APPLICATION_HOME="$START_DIR/conf"

# Параметр: -newJTSHome
# Формат: -newJTSHome <путь-к-каталогу>
# Описание:
# 	Полный путь к домашнему каталогу JTS установки версии 3.x.
# Значение по умолчанию:
# 	Новый домашний каталог приложения
# Ограничения:
#  - <путь-к-каталогу> должен существовать и оканчиваться на 'server/conf'
#
NEW_JTS_HOME=

# Параметр: -newJTSContextRoot
# Формат: -newJTSContextRoot <корень>
# Описание:
# 	Корневой контекст сервера 3.x JTS.
# Значение по умолчанию:
# 	jts
# Ограничения:
#  - <корень> должен быть допустимым именем каталога
#   (то есть без начального символа косой черты)
#
JTS_CONTEXT_ROOT=jts

# Параметр: -newApplicationTomcatHome
# Формат: -newApplicationTomcatHome <путь-к-каталогу>
# Описание:
# 	Путь к корневому каталогу Tomcat приложения в установке версии 3.x.
# Значение по умолчанию:
# 	<нет>
#
NEW_TOMCAT_HOME=

# Параметр: -newJTSTomcatHome
# Формат: -newJTSTomcatHome <путь-к-каталогу>
# Описание:
# 	Путь к корневому каталогу Tomcat JTS в установке версии 3.x.
# Значение по умолчанию:
# 	<нет>
#
NEW_JTS_TOMCAT_HOME=

# Параметр: -noPrompt
# Формат: -noPrompt
# Описание:
# 	Не показывать никаких приглашений (всегда использовать noPrompt) при выполнении команд repotools
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - Допустимо только пустое значение и значение 'noPrompt'
#
# NO_PROMPT=noPrompt
NO_PROMPT=

# Параметр: -overwrite
# Формат: -overwrite
# Описание:
# 	Принудительная замена (всегда использовать overwrite=yes) при выполнении команд repotools
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - Допустимо только пустое значение и значение 'overwrite=yes'
#
# OVERWRITE=overwrite=yes
OVERWRITE=

# Параметр: -noVerify
# Формат: -noVerify
# Описание:
# 	Не выполнять никаких проверок (всегда использовать noVerify) при выполнении команд repotools
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - Допустимо только пустое значение и значение 'noVerify'
#
# NO_VERIFY=noVerify
NO_VERIFY=

# Параметр: -importFromFile
# Формат: -importFromFile <путь-к-файлу>
# Описание:
# 	Импортировать содержимое файла tar в таблицы базы данных
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - Путь должен указывать на существующий и допустимый файл
#
IMPORT_FROM_FILE=

# Параметр: -noStepPrompt
# Формат: -noStepPrompt
# Описание:
# 	Не выводить запрос перед каждым этапом обновления
# Значение по умолчанию:
# 	false
# Ограничения:
#  - Допустимы только значения 'true' и 'false'
#
# NO_STEP_PROMPT=true
NO_STEP_PROMPT=false
